==> legato-dist-wps-1.1.2-dist.tar.gz: Legato-WPS-1.1.2/lib/WPS/Component/Polygon.js <==
/*
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

WPS.Component.Polygon = OpenLayers.Class(WPS.Component.AbstractGeometry, {
  geometryType : 'Polygon',

  createGeoInputControl : function(controlOptions) {
    if(Legato.Lang.ObjectUtils.isObject(controlOptions)){
      //i18n
      controlOptions.title = 'Zeichnet eine freie Geometrie.';
    }
    return new Legato.Control.DrawPolygon(this.layer, controlOptions);
  },

  createGeoModifyControl : function(controlOptions) {
    if(Legato.Lang.ObjectUtils.isObject(controlOptions)){
      //i18n
      controlOptions.title = 'Ändert die freie Geometrie.';
    }
    return new Legato.Control.ModifyPolygon(this.layer, controlOptions);
  },

  CLASS_NAME : 'WPS.Component.Polygon'
});

==> legato-dist-wps-2.0.0-dist.tar.gz: Legato-WPS-2.0.0/lib/WPS/Component/Polygon.js <==
/*
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

WPS.Component.Polygon = OpenLayers.Class(WPS.Component.AbstractGeometry, {
  geometryType : 'Polygon',

  createGeoInputControl : function() {
    return new Legato.Control.DrawPolygon(this.layer, {
      title : WPS.I18n.getMessage('WPS.Polygon.Draw'),
      mode : Legato.Control.DrawFeature.MODE_REPLACE_FEATURE,
      type : OpenLayers.Control.TYPE_TOGGLE,
      style : this.getDefaultStyle()
    });
  },

  createGeoModifyControl : function() {
    return new Legato.Control.ModifyPolygon(this.layer, {
      title : WPS.I18n.getMessage('WPS.Polygon.Edit'),
      mode : Legato.Control.ModifyFeature.MODE_RESHAPE,
      style : this.getDefaultStyle()
    });
  },

  getDefaultStyle : function(){
    return this.getNamedStyle('Polygon');
  },

  CLASS_NAME : 'WPS.Component.Polygon'
});
